==> haskell-unicode-show-0.1.0.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-show
version: 0.1.0.2
id: unicode-show-0.1.0.2-6s8ITh0yvVkKVGZhOzJs3U
key: unicode-show-0.1.0.2-6s8ITh0yvVkKVGZhOzJs3U
license: BSD3
copyright: 2016 Takayuki Muranushi
maintainer: muranushi@gmail.com
homepage: http://github.com/nushio3/unicode-show#readme
synopsis: print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.
    .
    See <http://github.com/nushio3/unicode-show#readme README> for usage.
    .
    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.
category: Text
author: Takayuki Muranushi
exposed: True
exposed-modules:
    Text.Show.Unicode
abi: f33e7545fbbe221a28aeb86edfe68217
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/unicode-show-0.1.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/unicode-show-0.1.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/unicode-show-0.1.0.2
hs-libraries: HSunicode-show-0.1.0.2-6s8ITh0yvVkKVGZhOzJs3U
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock
haddock-html: /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-show-0.1.0.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-show
version: 0.1.0.2
id: unicode-show-0.1.0.2-FGLMxwJiHGt3jyhkshfpEN
key: unicode-show-0.1.0.2-FGLMxwJiHGt3jyhkshfpEN
license: BSD3
copyright: 2016 Takayuki Muranushi
maintainer: muranushi@gmail.com
homepage: http://github.com/nushio3/unicode-show#readme
synopsis: print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.
    .
    See <http://github.com/nushio3/unicode-show#readme README> for usage.
    .
    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.
category: Text
author: Takayuki Muranushi
exposed: True
exposed-modules:
    Text.Show.Unicode
abi: 429eb9720a2d305f312613fe21761783
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/unicode-show-0.1.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/unicode-show-0.1.0.2
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/unicode-show-0.1.0.2
hs-libraries: HSunicode-show-0.1.0.2-FGLMxwJiHGt3jyhkshfpEN
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock
haddock-html: /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
